@@ -31,7 +31,9 @@ from mutagen.optimfrog import OptimFROG
 from mutagen.asf import ASF
 from mutagen.aiff import AIFF
 from mutagen.aac import AAC
+from mutagen.ac3 import AC3
 from mutagen.smf import SMF
+from mutagen.tak import TAK
 from mutagen.dsf import DSF
 from os import devnull
 
@@ -493,6 +495,10 @@ _FILETYPES = {
         os.path.join(DATA_DIR, "empty.aac"),
         os.path.join(DATA_DIR, "adif.aac"),
     ],
+    AC3: [
+        os.path.join(DATA_DIR, "silence-44-s.ac3"),
+        os.path.join(DATA_DIR, "silence-44-s.eac3"),
+    ],
     ASF: [
         os.path.join(DATA_DIR, "silence-1.wma"),
         os.path.join(DATA_DIR, "silence-2.wma"),
@@ -519,6 +525,10 @@ _FILETYPES = {
     SMF: [
         os.path.join(DATA_DIR, "sample.mid"),
     ],
+    TAK: [
+        os.path.join(DATA_DIR, "silence-44-s.tak"),
+        os.path.join(DATA_DIR, "has-tags.tak"),
+    ],
     DSF: [
         os.path.join(DATA_DIR, '2822400-1ch-0s-silence.dsf'),
         os.path.join(DATA_DIR, '5644800-2ch-s01-silence.dsf'),
