@@ -2,27 +2,17 @@
 
 import os
 import sys
-import imp
-import warnings
+import importlib
 
-import mutagen
 from mutagen._compat import StringIO, text_type, PY2
-from mutagen._toolsutil import fsnative, is_fsnative
+from mutagen._senf import fsnative
 
 from tests import TestCase
 
 
 def get_var(tool_name, entry="main"):
-    tool_path = os.path.join(
-        mutagen.__path__[0], "..", "tools", fsnative(tool_name))
-    dont_write_bytecode = sys.dont_write_bytecode
-    sys.dont_write_bytecode = True
-    try:
-        with warnings.catch_warnings():
-            warnings.simplefilter("ignore", DeprecationWarning)
-            mod = imp.load_source(tool_name, tool_path)
-    finally:
-        sys.dont_write_bytecode = dont_write_bytecode
+    mod = importlib.import_module(
+        "mutagen._tools.%s" % tool_name.replace("-", "_"))
     return getattr(mod, entry)
 
 
@@ -38,7 +28,7 @@ class _TTools(TestCase):
 
     def call2(self, *args):
         for arg in args:
-            self.assertTrue(is_fsnative(arg))
+            self.assertTrue(isinstance(arg, fsnative))
         old_stdout = sys.stdout
         old_stderr = sys.stderr
         try:
@@ -54,7 +44,7 @@ class _TTools(TestCase):
             out_val = out.getvalue()
             err_val = err.getvalue()
             if os.name == "nt" and PY2:
-                encoding = getattr(sys.stdout, "encoding", None) or "utf-8"
+                encoding = getattr(sys.stdout, "encoding", None) or "mbcs"
                 out_val = text_type(out_val, encoding)
                 err_val = text_type(err_val, encoding)
             return (ret, out_val, err_val)
